pub struct DummyCoreSyncSvc(/* private fields */);Expand description
A dummy core sync service that just returns static CoreSyncData.
Implementations
Sourceimpl DummyCoreSyncSvc
impl DummyCoreSyncSvc
Sourcepub const fn static_mainnet_genesis() -> Self
pub const fn static_mainnet_genesis() -> Self
Returns a DummyCoreSyncSvc that will just return the mainnet genesis CoreSyncData.
Sourcepub const fn static_testnet_genesis() -> Self
pub const fn static_testnet_genesis() -> Self
Returns a DummyCoreSyncSvc that will just return the testnet genesis CoreSyncData.
Sourcepub const fn static_stagenet_genesis() -> Self
pub const fn static_stagenet_genesis() -> Self
Returns a DummyCoreSyncSvc that will just return the stagenet genesis CoreSyncData.
Sourcepub const fn static_custom(data: CoreSyncData) -> Self
pub const fn static_custom(data: CoreSyncData) -> Self
Returns a DummyCoreSyncSvc that will return the provided CoreSyncData.