HandshakerBuilder

Struct HandshakerBuilder 

pub struct HandshakerBuilder<N: NetworkZone, T: Transport<N>, AdrBook = DummyAddressBook, CSync = DummyCoreSyncSvc, ProtoHdlrMkr = MapErr<Shared<DummyProtocolRequestHandler>, fn(Infallible) -> BoxError>, BrdcstStrmMkr = fn(InternalPeerID<<N as NetworkZone>::Addr>) -> Pending<BroadcastMessage>> { /* private fields */ }
A HandShaker Service builder.

This builder applies default values to make usage easier, behaviour and drawbacks of the defaults are documented on the with_* method to change it, for example HandshakerBuilder::with_protocol_request_handler_maker.

If you want to use any network other than Mainnet you will need to change the core sync service with HandshakerBuilder::with_core_sync_svc, see that method for details.

Implementations

Source

impl<N: NetworkZone, T: Transport<N>> HandshakerBuilder<N, T>

pub fn new( our_basic_node_data: BasicNodeData, transport_client_config: T::ClientConfig, ) -> Self

Creates a new builder with our node’s basic node data.

Source

impl<N: NetworkZone, T: Transport<N>, AdrBook, CSync, ProtoHdlr, BrdcstStrmMkr> HandshakerBuilder<N, T, AdrBook, CSync, ProtoHdlr, BrdcstStrmMkr>

pub fn with_address_book<NAdrBook>( self, new_address_book: NAdrBook, ) -> HandshakerBuilder<N, T, NAdrBook, CSync, ProtoHdlr, BrdcstStrmMkr>
where NAdrBook: AddressBook<N> + Clone,

Changes the address book to the provided one.

Default Address Book

The default address book is used if this function is not called.

The default address book’s only drawback is that it does not keep track of peers and therefore bans.

pub fn with_core_sync_svc<NCSync>( self, new_core_sync_svc: NCSync, ) -> HandshakerBuilder<N, T, AdrBook, NCSync, ProtoHdlr, BrdcstStrmMkr>
where NCSync: CoreSyncSvc + Clone,

Changes the core sync service to the provided one.

The core sync service should keep track of our nodes core sync data.

Default Core Sync Service

The default core sync service is used if this method is not called.

The default core sync service will just use the mainnet genesis block, to use other network’s genesis see DummyCoreSyncSvc::static_stagenet_genesis and DummyCoreSyncSvc::static_testnet_genesis. The drawbacks to keeping this the default is that it will always return the mainnet genesis as our nodes sync info, which means peers won’t know our actual chain height, this may or may not be a problem for different use cases.

pub fn with_protocol_request_handler_maker<NProtoHdlrMkr>( self, new_protocol_request_svc_maker: NProtoHdlrMkr, ) -> HandshakerBuilder<N, T, AdrBook, CSync, NProtoHdlrMkr, BrdcstStrmMkr>
where NProtoHdlrMkr: ProtocolRequestHandlerMaker<N> + Clone,

Changes the protocol request handler maker, which creates the service that handles ProtocolRequests to our node.

Default Protocol Request Handler

The default service maker will create services that will not respond to any protocol requests, this should not be an issue as long as peers do not think we are ahead of them, if they do they will send requests for our blocks, and we won’t respond which will cause them to disconnect.

pub fn with_broadcast_stream_maker<NBrdcstStrmMkr, BrdcstStrm>( self, new_broadcast_stream_maker: NBrdcstStrmMkr, ) -> HandshakerBuilder<N, T, AdrBook, CSync, ProtoHdlr, NBrdcstStrmMkr>
where BrdcstStrm: Stream<Item = BroadcastMessage> + Send + 'static, NBrdcstStrmMkr: Fn(InternalPeerID<N::Addr>) -> BrdcstStrm + Clone + Send + 'static,

Changes the broadcast stream maker, which is used to create streams that yield messages to broadcast.

Default Broadcast Stream Maker

The default broadcast stream maker just returns [stream::Pending], i.e. the returned stream will not produce any messages to broadcast, this is not a problem if your use case does not require broadcasting messages.

pub fn with_peer_sync_callback(self, on_peer_sync: PeerSyncCallback) -> Self

Sets the callback invoked with a peer’s CoreSyncData.

Default

No callback is set by default.

pub fn with_connection_parent_span(self, connection_parent_span: Span) -> Self

Changes the parent [Span] of the connection task to the one provided.

Default Connection Parent Span

The default connection span will be [Span::none].

pub fn build(self) -> HandShaker<N, T, AdrBook, CSync, ProtoHdlr, BrdcstStrmMkr>

Builds the HandShaker.